@@ -1,7 +1,7 @@
 import click
 
-from marvelcli import utils
-from marvelcli.folder import folder_queries
+import utils
+from folder import folder_queries
 
 # Limited by the API to only be able to create folders at the moment.
 
