@@ -1,7 +1,7 @@
 import click
 
-from marvelcli import utils
-from marvelcli.group import group_queries
+import utils
+from group import group_queries
 
 @click.option('-g', '--group-pk', type=int, multiple=True, help='Use this flag for each group to be deleted')
 @click.option('-a', '--auth', type=str, help='Auth your request')
@@ -15,16 +15,21 @@ def delete_groups(group_pk: list, auth: str):
 	if r.status_code != 200:
 		click.echo(json_data['data']['deleteGroups']['error']['message'])
 	else:
-		data_success = json_data['data']['deleteGroups']['succeeded']
-		data_failed = json_data['data']['deleteGroups']['failed']
+		if not group_pk:
+			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
+		else:
+			data_success = json_data['data']['deleteGroups']['succeeded']
+			data_failed = json_data['data']['deleteGroups']['failed']
 
-		if data_success:
-			click.echo("\nThe following groups were deleted from your workspace successfully: %s." % ', '.join(data_success))
+			if data_success:
+				click.echo("\nThe following groups were deleted from your workspace successfully: %s" % data_success)
 
-		if data_failed:
-			click.echo('\nThe following groups could not be deleted from your workspace:')
-			for f in data_failed:
-				click.echo("%s  - %s\n" % (f.get('groupPk'), f.get('message')))
+			if data_failed:
+				click.echo('\nThe following groups could not be deleted from your workspace:')
+				for f in data_failed:
+					click.echo("%s  - %s" % (f.get('groupPk'), f.get('message')))
+
+			click.echo("\n")
 
 @click.option('-n', '--name', type=str, help='Name of group')
 @click.option('-a', '--auth', type=str, help='Auth your request')
@@ -47,57 +52,68 @@ def create_group(name: str, auth: str):
 @click.option('-e', '--email', type=str, multiple=True, help='Use this flag for each email address you want added to your group')
 @click.option('-a', '--auth', type=str, help='Auth your request')
 @click.command()
-def add_members_to_group(group_pk: int, emails: list, auth: str):
+def add_members_to_group(group_pk: int, email: list, auth: str):
 	"""Add members to a group"""
-	params = {'teamPk': group_pk,'emails': emails}
+	params = {'teamPk': group_pk,'emails': email}
 	query = group_queries.add_members_query
 	r, json_data = utils.make_request(auth, query, params)
 
 	if r.status_code != 200:
-		click.echo(json_data['data']['addMembersToTeam']['error']['message'])
+		if not group_pk:
+			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
+		else:
+			click.echo(json_data['data']['addMembersToTeam']['error']['message'])
 	else:
-		data_success = json_data['data']['addMembersToTeam']['succeeded']
-		data_failed = json_data['data']['addMembersToTeam']['failed']
+		if not email:
+			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
+		else:
+			data_success = json_data['data']['addMembersToTeam']['succeeded']
+			data_failed = json_data['data']['addMembersToTeam']['failed']
+			if data_success:
+				successful_emails = []
+				for s in data_success:
+					successful_emails.append(s.get('email'))
 
-		if data_success:
-			successful_emails = []
-			for s in data_success:
-				successful_emails.append(s.get('email'))
+				click.echo("\nThe following people were successfully added to group %s: %s" % (group_pk, ', '.join(successful_emails)))
 
-			click.echo("\n The following people were successfully added to group %s: %s" % (pk, ', '.join(successful_emails)))
+			if data_failed:
+				click.echo('\nThe following people could not be added to group %s for the following reasons:' % (group_pk))
+				for f in data_failed:
+					click.echo("%s  - %s" % (f.get('email'), f.get('message')))
 
-		if data_failed:
-			click.echo('The following people could not be added to group %s:' % (pk))
-			for f in data_failed:
-				click.echo("%s  - %s \n " % (f.get('email'), f.get('message')))
+			click.echo("\n")
 
 @click.option('-g', '--group-pk', type=int, help='Pk of the group you want to remove members from')
 @click.option('-e', '--email', type=str, multiple=True, help='Use this flag for each email address you want removed from your group')
 @click.option('-a', '--auth', type=str, help='Auth your request')
 @click.command()
-def remove_members_from_group(group_pk: int, emails: list, auth: str):
+def remove_members_from_group(group_pk: int, email: list, auth: str):
 	"""Remove members from a group"""
-	params = {'teamPk': group_pk,'emails': emails}
+	params = {'teamPk': group_pk,'emails': email}
 	query = group_queries.remove_members_query
 	r, json_data = utils.make_request(auth, query, params)
 
 	if r.status_code != 200:
-		click.echo(json_data['data']['removeMembersFromTeam']['error']['message'])
+		if not group_pk:
+			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
+		else:
+			click.echo(json_data['data']['removeMembersFromTeam']['error']['message'])
 	else:
-		data_success = json_data['data']['removeMembersFromTeam']['succeeded']
-		data_failed = json_data['data']['removeMembersFromTeam']['failed']
+		if not email:
+			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
+		else:
+			data_success = json_data['data']['removeMembersFromTeam']['succeeded']
+			data_failed = json_data['data']['removeMembersFromTeam']['failed']
 
-		if data_success:
-			successful_emails = []
-			for s in data_success:
-				successful_emails.append(s.get('email'))
+			if data_success:
+				click.echo("\nThe following people were successfully removed from group %s: %s" % (group_pk, data_success))
 
-			click.echo("The following people were successfully removed from group %s: %s" % (pk, ', '.join(successful_emails)))
+			if data_failed:
+				click.echo('\nThe following people could not be removed from group %s:' % (group_pk))
+				for f in data_failed:
+					click.echo("%s  - %s" % (f.get('email'), f.get('message')))
 
-		if data_failed:
-			click.echo('The following people could not be removed from group %s:' % (pk))
-			for f in data_failed:
-				click.echo("%s  - %s" % (f.get('email'), f.get('message')))
+			click.echo("\n")
 
 @click.option('-g', '--group-pk', type=int, help='Pk of the group you want to update the name for')
 @click.option('-n', '--name', type=str, help='New name for your group')
